@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """A getter for DepMap."""
 
 import requests
@@ -21,7 +19,7 @@ class DepMapGetter(Getter):
 
     def get(self) -> str:
         """Get the latest DepMap version number."""
-        res = requests.get(URL)
+        res = requests.get(URL, timeout=15)
         latest = next(release for release in res.json()["releaseData"] if release["isLatest"])
         return latest["releaseName"][len("DepMap Public ") :]
 
