@@ -1,22 +1,21 @@
-# -*- coding: utf-8 -*-
-
 """Version information for bioversions."""
 
 import os
-from subprocess import CalledProcessError, check_output  # noqa: S404
+from subprocess import CalledProcessError, check_output
 
 __all__ = [
     "VERSION",
+    "get_git_hash",
 ]
 
-VERSION = "0.5.499"
+VERSION = "0.8.82"
 
 
 def get_git_hash() -> str:
     """Get the bioversions git hash."""
     with open(os.devnull, "w") as devnull:
         try:
-            ret = check_output(  # noqa: S603,S607
+            ret = check_output(
                 ["git", "rev-parse", "HEAD"],
                 cwd=os.path.dirname(__file__),
                 stderr=devnull,
